import { DIRNAMEENUM } from "../config/enums/enum";
import { ERRORENUM } from "../config/enums/errorEnum";
import { BizError } from "../util/bizError";
import { eccEnumValue } from "../util/verificationEnum";

var formidable = require("formidable");
const path = require('path');

export async function parseFormParam(req, res, next) {
    if (!req.headers) req.headers = {};
    let upType = req.headers.uptype;

    if (isNaN(upType)) return next(new BizError(ERRORENUM.上传时缺失关键参数, `传入参数类型不符合规则${upType}` ));
    let eccSuccess = eccEnumValue( DIRNAMEENUM, parseInt(upType));
    if (!eccSuccess) return next(new BizError(ERRORENUM.上传时缺失关键参数, `传入参数不符合规则${upType}` ));

    var form = new formidable.IncomingForm({
        uploadDir:path.join(__dirname.substring(0,__dirname.indexOf("out")),'files', 'yfs','files', `${upType}`),
        maxFildsSize:10*1024*1024,
        keepExtensions:true
    });
   

    form.parse(req, (err, fields, files)=>{
        if (err) {
            return next(err);
        }
        else {
            req.fields = fields;
            req.files = files;
            req.files.formData.upType = upType;
            
            if (!files.formData) {
                return next(new BizError(ERRORENUM.文件上传失败) );
            }
            if ( files.formData.type == 'image/png') {
                req.fileType = '.png';
                return next();
            } else if (files.formData.type == 'image/jpg' || files.formData.type == 'image/jpeg') {
                req.fileType = '.jpg';
                return next();
            } else if (files.formData.type == "application/vnd.openxmlformats-officedocument.wordprocessingml.document") {
                req.fileType = '.docx';
                return next();
            } else if (files.formData.type == "application/msword") {
                req.fileType = '.doc';
                return next();
            } else if (files.formData.type == "application/pdf") {
                req.fileType = '.pdf';
                return next();
            }else {
                return next(new BizError(ERRORENUM.只能上传doc或docx或png或jpg图片) )
            }
        }
    })
}
